Enum Error

pub enum Error {
    Arena(Error),
    ValueTooLarge {
        size: usize,
        maximum_size: usize,
    },
    KeyTooLarge {
        size: usize,
        maximum_size: usize,
    },
    EntryTooLarge {
        size: u64,
        maximum_size: u64,
    },
    InvalidHeight {
        height: Height,
        max_height: Height,
    },
    ArenaTooSmall,
    IO(Error),
}
Available on crate feature bounded only.
Error type for the SkipMaps.

Variants



Arena(Error)

Indicates that the arena is full



ValueTooLarge

Indicates that the value is too large to be stored in the SkipMap.

Fields

size: usize

The size of the value.

maximum_size: usize

The max size of the value.



KeyTooLarge

Indicates that the key is too large to be stored in the SkipMap.

Fields

size: usize

The size of the key.

maximum_size: usize

The max size of the key.



EntryTooLarge

Indicates that the entry is too large to be stored in the SkipMap.

Fields

size: u64

The size of the entry.

maximum_size: u64

The max size of the entry.



InvalidHeight

Indicates that the height of the SkipMap is too large.

Fields

height: Height

The height of the SkipMap.

max_height: Height

The max height of the SkipMap.



ArenaTooSmall

Arena too small



IO(Error)

I/O error

Implementations

Source

impl Error

pub const fn read_only() -> Error

Returns a read only error.