pub enum Error {
Arena(Error),
ValueTooLarge {
size: usize,
maximum_size: usize,
},
KeyTooLarge {
size: usize,
maximum_size: usize,
},
EntryTooLarge {
size: u64,
maximum_size: u64,
},
InvalidHeight {
height: Height,
max_height: Height,
},
ArenaTooSmall,
IO(Error),
}Available on crate feature
bounded only.Expand description
Error type for the SkipMaps.
Variants
Arena(Error)
Indicates that the arena is full
ValueTooLarge
Indicates that the value is too large to be stored in the SkipMap.
KeyTooLarge
Indicates that the key is too large to be stored in the SkipMap.
EntryTooLarge
Indicates that the entry is too large to be stored in the SkipMap.
InvalidHeight
Indicates that the height of the SkipMap is too large.
ArenaTooSmall
Arena too small
IO(Error)
I/O error
Implementations